@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from util import WebHelpersTestCase
 import unittest
 
@@ -80,6 +81,11 @@ class TestFormTagHelper(WebHelpersTestCase):
             '<input checked="checked" id="num_people_5" name="num_people" type="radio" value="5" />'
         )
 
+        self.assertEqual(
+            radio_button("people", u'josé', checked=True),
+            '<input checked="checked" id="people_jos" name="people" type="radio" value="jos&#233;" />'
+        )
+
     def test_select(self):
         self.assertEqual(
             select("people", "<option>justin</option>"),
